@@ -1,4 +1,4 @@
-"""Dominus SDK Namespaces v2.7"""
+"""Dominus SDK Namespaces v2.8"""
 from .secrets import SecretsNamespace
 from .db import DbNamespace
 from .redis import RedisNamespace
@@ -10,6 +10,7 @@ from .open import OpenNamespace
 from .health import HealthNamespace
 from .portal import PortalNamespace
 from .courier import CourierNamespace
+from .workflow import WorkflowNamespace
 from .ai import (
     AiNamespace,
     RagSubNamespace,
@@ -30,6 +31,7 @@ __all__ = [
     "HealthNamespace",
     "PortalNamespace",
     "CourierNamespace",
+    "WorkflowNamespace",
     "AiNamespace",
     "RagSubNamespace",
     "ArtifactsSubNamespace",
