@@ -355,6 +355,10 @@ class Dominus:
         from .namespaces.ai import AiNamespace
         self.ai = AiNamespace(self)
 
+        # Workflow namespace (workflow-manager service)
+        from .namespaces.workflow import WorkflowNamespace
+        self.workflow = WorkflowNamespace(self)
+
         # Cache for JWT public key
         self._public_key_cache = None
 
